require 'file'
require 'simpleutils'

-- Read the request and pass it on
function main(Data)
   local Req = net.http.parseRequest{data=Data}
   ServeRequest(Req)
end

-- Decide if it's a web service call, or a file. If neither, serve the main page.
function ServeRequest(Request)
   local ImportantUri = Request.location:sub(11)
   if DoAction(ImportantUri, Request.params) then return 'Served Json' end
   if ServeFile(ImportantUri) then return 'Served file' end
   Default()
   return 'Served default screen'
end

-- Look for an app action.
-- If we find one, run it with the parameters that came in with the request, then serve the result.
function DoAction(Keyword, Params) 
   local Func = ActionMap[Keyword] 
   if (Func) then
      local StuffToSendBack = Func(Params)
      net.http.respond{entity_type='text/json', body=json.serialize{data=StuffToSendBack}}
      return true
   end
   return nil
end

-- Look for a file.
-- If we find one, get its contents and serve them.
function ServeFile(Uri)
   if #Uri == 0 then
      return false 
   end
   local Content = GetFile(Uri)
   if not Content then 
      return false
   end
   local Entity = FindEntity(Uri)
   trace(Content)
   if (Content) then
      net.http.respond{body=Content, entity_type=Entity}
      return true
   end
   return false
end

-- Serve the main page.
function Default() 
   ServeFile('/tiny_page.html')
end

-- Here is an action.
function logs(Params)
   local Wayback = {
      day = 86400,
      week = 604800,
      month = 2419200,
      year = 31536000
   }
   local Time = os.ts.date("%Y/%m/%d %X", os.ts.time() - Wayback[Params.time])
   trace(Time)
   trace(os.ts.time())
   trace(Wayback[Params.time])
   local LogList = net.http.post{
      url='http://localhost:6543/api_query',
      auth={username='admin', password='password'}, 
      parameters={type='message', after=Time, filter=Params.type},
      live=true
   }
   local LogTree = xml.parse{data=LogList}
   return {count = #LogTree.export - 1}   
end

-- List of URLs that trigger app actions.
-- Yes, there is only one.
ActionMap = {
   ['/logs'] = logs,
}
